==> seedsui-react-5.8.42.tgz: package/lib/Map/components/Result/index.js <==
var _excluded = ["title", "subTitle", "extra", "children"];
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import React, { useRef, forwardRef, useImperativeHandle } from 'react';
var Result = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var title = _ref.title,
    subTitle = _ref.subTitle,
    extra = _ref.extra,
    children = _ref.children,
    props = _objectWithoutProperties(_ref, _excluded);
  var rootRef = useRef(null);

  // 节点
  useImperativeHandle(ref, function () {
    return {
      rootDOM: rootRef.current,
      getRootDOM: function getRootDOM() {
        return rootRef.current;
      }
    };
  });
  return /*#__PURE__*/React.createElement("div", _extends({}, props, {
    className: 'map map-result' + (props.className ? ' ' + props.className : ''),
    ref: rootRef
  }), /*#__PURE__*/React.createElement("div", {
    className: "map-result-title"
  }, title), /*#__PURE__*/React.createElement("div", {
    className: "map-result-subtitle"
  }, subTitle), children, extra);
});
export default Result;

==> seedsui-react-5.8.44.tgz: package/lib/Map/components/Result/index.js <==
var _excluded = ["retry", "title", "subTitle", "extra"];
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import React, { useRef, forwardRef, useImperativeHandle } from 'react';
import Button from "./../../../Button";
import locale from "./../../../locale";
var Result = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var retry = _ref.retry,
    title = _ref.title,
    subTitle = _ref.subTitle,
    extra = _ref.extra,
    props = _objectWithoutProperties(_ref, _excluded);
  var rootRef = useRef(null);

  // 节点
  useImperativeHandle(ref, function () {
    return {
      rootDOM: rootRef.current,
      getRootDOM: function getRootDOM() {
        return rootRef.current;
      }
    };
  });
  return /*#__PURE__*/React.createElement("div", _extends({}, props, {
    className: 'map-result' + (props.className ? ' ' + props.className : ''),
    ref: rootRef
  }), /*#__PURE__*/React.createElement("div", {
    className: "map-result-title"
  }, title), /*#__PURE__*/React.createElement("div", {
    className: "map-result-subtitle"
  }, subTitle), extra, typeof retry === 'function' && /*#__PURE__*/React.createElement(Button, {
    className: "map-result-button-retry primary",
    onClick: retry
  }, locale('重试')));
});
export default Result;
